@@ -81,6 +81,9 @@ void InitSchema::act(const FieldRef<V>& field)
   if (idField_)
     flags |= FieldInfo::NaturalId; // Natural id
 
+  if ((field.flags() & FieldRef<V>::AuxId) || (fkFlags_ & PtrRef<V>::AuxId))
+    flags |= FieldInfo::AuxId; // Aux id (appended in update and delete)
+  
   if (!foreignKeyName_.empty())
     // Foreign key
     mapping_.fields.push_back
@@ -104,6 +107,7 @@ void InitSchema::actPtr(const PtrRef<C>& field)
     foreignKeyName_ = field.name();
     foreignKeyTable_ = mapping->tableName;
     fkConstraints_ = field.fkConstraints();
+    fkFlags_ = field.flags();
   }
 
   field.visit(*this, &session_);
@@ -112,6 +116,7 @@ void InitSchema::actPtr(const PtrRef<C>& field)
     foreignKeyName_.clear();
     foreignKeyTable_.clear();
     fkConstraints_ = 0;
+    fkFlags_ = 0;
   }
 }
 
@@ -335,6 +340,28 @@ void LoadDbAction<C>::actId(ptr<D>& value, const std::string& name, int size,
      * SaveDbAction
      */
 
+template <class C>
+void SaveBaseAction::visitAuxIds(C& obj)
+{
+  auxIdOnly_ = true;
+  pass_ = Self;
+
+  persist<C>::apply(obj, *this);
+}
+
+template<typename V>
+void SaveBaseAction::actId(V& value, const std::string& name, int size)
+{
+  /* Only used from within visitAuxIds() */
+}
+
+template<class D>
+void SaveBaseAction::actId(ptr<D>& value, const std::string& name, int size,
+			   int fkConstraints)
+{ 
+  /* Only used from within visitAuxIds() */
+}
+
 template<class C>
 void SaveBaseAction::actPtr(const PtrRef<C>& field)
 {
@@ -348,10 +375,18 @@ void SaveBaseAction::actPtr(const PtrRef<C>& field)
 
     break;
   case Self:
-    bindNull_ = !field.value();
-    field.visit(*this, session());
-    bindNull_ = false;
+    if (auxIdOnly_ && !(field.flags() & PtrRef<C>::AuxId))
+      return;
 
+    {
+      bool wasAuxIdOnly = auxIdOnly_;
+      auxIdOnly_ = false;
+      bindNull_ = !field.value();
+      field.visit(*this, session());
+      bindNull_ = false;
+      auxIdOnly_ = wasAuxIdOnly;
+    }
+    
     break;
   case Sets:
     break;
@@ -361,6 +396,9 @@ void SaveBaseAction::actPtr(const PtrRef<C>& field)
 template<class C>
 void SaveBaseAction::actWeakPtr(const WeakPtrRef<C>& field)
 {
+  if (auxIdOnly_)
+    return;
+
   switch (pass_) {
   case Dependencies:
     break;
@@ -378,6 +416,9 @@ void SaveBaseAction::actWeakPtr(const WeakPtrRef<C>& field)
 template<class C>
 void SaveBaseAction::actCollection(const CollectionRef<C>& field)
 {
+  if (auxIdOnly_)
+    return;
+
   switch (pass_) {
   case Dependencies:
     break;
@@ -500,7 +541,7 @@ void SaveDbAction<C>::visit(C& obj)
 
     if (!isInsert_) {
       MetaDboBase *dbo = dynamic_cast<MetaDboBase *>(&dbo_);
-      dbo->bindId(statement_, column_);
+      dbo->bindModifyId(statement_, column_);
 
       if (mapping().versionFieldName) {
 	// when saved in the transaction, we will be at version() + 1
